==> cloud-3.0.0-rc1.tar.gz: cloud/modules/cloud_service_providers/openstack/src/Controller/ApiController.php <==
<?php

namespace Drupal\openstack\Controller;

use Drupal\aws_cloud\Service\Ec2\Ec2Service;
use Drupal\cloud\Plugin\cloud\config\CloudConfigPluginManagerInterface;
use Drupal\cloud\Traits\CloudContentEntityTrait;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Messenger\Messenger;
use Drupal\Core\Render\RendererInterface;
use Drupal\views\Views;
use Drupal\openstack\Service\OpenStackServiceFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;
use Symfony\Component\HttpFoundation\Response;

/**
 * Api controller for interacting with OpenStack.
 */
class ApiController extends ControllerBase implements ApiControllerInterface {

  use CloudContentEntityTrait;

  /**
   * The OpenStack Service.
   *
   * @var \Drupal\openstack\Service\OpenStackServiceFactoryInterface
   */
  private $openStackServiceFactory;

  /**
   * The Messenger service.
   *
   * @var \Drupal\Core\Messenger\Messenger
   */
  protected $messenger;

  /**
   * Request stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  private $requestStack;

  /**
   * The cloud service provider plugin manager (CloudConfigPluginManager).
   *
   * @var \Drupal\cloud\Plugin\cloud\config\CloudConfigPluginManagerInterface
   */
  protected $cloudConfigPluginManager;

  /**
   * Renderer service.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  private $renderer;

  /**
   * ApiController constructor.
   *
   * @param \Drupal\openstack\Service\OpenStackServiceFactoryInterface $openstack_service_factory
   *   Object for interfacing with OpenStack Service.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The Entity type manager.
   * @param \Drupal\Core\Messenger\Messenger $messenger
   *   Messenger Object.
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   Request stack object.
   * @param \Drupal\cloud\Plugin\cloud\config\CloudConfigPluginManagerInterface $cloud_config_plugin_manager
   *   The cloud service provider plugin manager (CloudConfigPluginManager).
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   The renderer service.
   */
  public function __construct(OpenStackServiceFactoryInterface $openstack_service_factory,
                              EntityTypeManagerInterface $entityTypeManager,
                              Messenger $messenger,
                              RequestStack $request_stack,
                              CloudConfigPluginManagerInterface $cloud_config_plugin_manager,
                              RendererInterface $renderer) {
    $this->openStackServiceFactory = $openstack_service_factory;
    $this->entityTypeManager = $entityTypeManager;
    $this->messenger = $messenger;
    $this->requestStack = $request_stack;
    $this->cloudConfigPluginManager = $cloud_config_plugin_manager;
    $this->renderer = $renderer;
  }

  /**
   * Dependency Injection.
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   Instance of ContainerInterface.
   *
   * @return ApiController
   *   return created object.
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('openstack.factory'),
      $container->get('entity_type.manager'),
      $container->get('messenger'),
      $container->get('request_stack'),
      $container->get('plugin.manager.cloud_config_plugin'),
      $container->get('renderer')
    );
  }

  /**
   * Update message after refresh resources.
   *
   * @param string $resource_type
   *   Entity type name.
   * @param array $updated
   *   Updated statuses.
   */
  protected function updateMessages($resource_type, array $updated) {
    $labels = $this->getDisplayLabels($resource_type);
    if (isset($updated[0])) {
      if ($updated[0]) {
        $this->messageUser($this->t('Updated @resource_name.', ['@resource_name' => $labels['plural']]));
      }
      else {
        $this->messageUser($this->t('Unable to update @resource_name.', ['@resource_name' => $labels['plural']]), 'error');
      }
    }
    Ec2Service::clearCacheValue();
  }

  /**
   * Update instances.
   *
   * @param string $cloud_context
   *   Cloud context string.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Redirect to instance list.
   */
  public function updateInstanceList($cloud_context = '') {
    return $this->updateResourceList('openstack_instance', $cloud_context);
  }

  /**
   * Update images.
   *
   * @param string $cloud_context
   *   Cloud context string.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Redirect to image list.
   */
  public function updateImageList($cloud_context = '') {
    return $this->updateResourceList('openstack_image', $cloud_context);
  }

  /**
   * Update keypairs.
   *
   * @param string $cloud_context
   *   Cloud context string.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Redirect to keypair list.
   */
  public function updateKeyPairList($cloud_context = '') {
    return $this->updateResourceList('openstack_key_pair', $cloud_context);
  }

  /**
   * Update security groups.
   *
   * @param string $cloud_context
   *   Cloud context string.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Redirect to security group list.
   */
  public function updateSecurityGroupList($cloud_context = '') {
    return $this->updateResourceList('openstack_security_group', $cloud_context);
  }

  /**
   * Update volumes.
   *
   * @param string $cloud_context
   *   Cloud context string.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Redirect to volume list.
   */
  public function updateVolumeList($cloud_context = '') {
    return $this->updateResourceList('openstack_volume', $cloud_context);
  }

  /**
   * Update snapshots.
   *
   * @param string $cloud_context
   *   Cloud context string.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Redirect to snapshot list.
   */
  public function updateSnapshotList($cloud_context = '') {
    return $this->updateResourceList('openstack_snapshot', $cloud_context);
  }

  /**
   * Update network interfaces.
   *
   * @param string $cloud_context
   *   Cloud context string.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Redirect to network interface list.
   */
  public function updateNetworkInterfaceList($cloud_context = '') {
    return $this->updateResourceList('openstack_network_interface', $cloud_context);
  }

  /**
   * Update floating ips.
   *
   * @param string $cloud_context
   *   Cloud context string.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Redirect to floating ip list.
   */
  public function updateFloatingIpList($cloud_context = '') {
    return $this->updateResourceList('openstack_floating_ip', $cloud_context);
  }

  /**
   * {@inheritdoc}
   */
  public function updateAll() {
    $regions = $this->requestStack->getCurrentRequest()->query->get('regions');
    if ($regions === NULL) {
      $this->messageUser($this->t('No region specified'), 'error');
    }
    else {
      $regions_array = explode(',', $regions);

      foreach ($regions_array ?: [] as $region) {
        $entity = $this->entityTypeManager()->getStorage('cloud_config')
          ->loadByProperties(
            [
              'cloud_context' => $region,
            ]);
        if ($entity) {
          openstack_update_resources(array_shift($entity));
        }
      }

      $this->messageUser($this->t('Creating cloud service provider was performed successfully.'));
      drupal_flush_all_caches();
    }
    return $this->redirect('entity.cloud_config.collection');
  }

  /**
   * {@inheritdoc}
   */
  public function listImageCallback($cloud_context) {
    return $this->getViewResponse('openstack_image');
  }

  /**
   * Helper method to get views output.
   *
   * @param string $view_id
   *   The ID of list view.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   The response of list view.
   *
   * @throws \Exception
   *   Thrown when an object is passed in which cannot be printed.
   */
  private function getViewResponse($view_id) {
    $view = Views::getView($view_id);

    // Set the display machine name.
    $view->setDisplay('list');

    // Render the view as html, and return it as a response object.
    $build = $view->executeDisplay();
    return new Response($this->renderer->render($build));
  }

  /**
   * Helper method to add messages for the end user.
   *
   * @param string $message
   *   The message.
   * @param string $type
   *   The message type: error or message.
   */
  private function messageUser($message, $type = 'message') {
    switch ($type) {
      case 'error':
        $this->messenger->addError($message);
        break;

      case 'message':
        $this->messenger->addStatus($message);
      default:
        break;
    }
  }

  /**
   * Helper method to update entities.
   *
   * @param string $entity_type_name
   *   The entity type name.
   * @param string $cloud_context
   *   The cloud context.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   An associative array with a redirect route and any parameters to build
   *   the route.
   */
  private function updateResourceList($entity_type_name, $cloud_context) {
    if (empty($cloud_context)) {
      return $this->updateAllResourceList($entity_type_name);
    }

    $labels = $this->getDisplayLabels($entity_type_name);
    $update_method_name = 'update' . self::getCamelCaseWithoutWhitespace($labels['plural']);
    $openstack_service = $this->openStackServiceFactory->get($cloud_context);
    $updated = $openstack_service->$update_method_name();

    if ($updated !== FALSE) {
      $this->messageUser($this->t('Updated @name.', ['@name' => $labels['plural']]));
    }
    else {
      $this->messageUser($this->t('Unable to update @name.', ['@name' => $labels['plural']]), 'error');
    }

    // Update the cache.
    Ec2Service::clearCacheValue();

    return $this->redirect("view.$entity_type_name.list", [
      'cloud_context' => $cloud_context,
    ]);
  }

  /**
   * Helper method to update all resource list.
   *
   * @param string $entity_type_name
   *   The entity type name.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   An associative array with a redirect route and any parameters to build
   *   the route.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  private function updateAllResourceList($entity_type_name) {
    $cloud_configs = $this->entityTypeManager()
      ->getStorage('cloud_config')
      ->loadByProperties([
        'type' => 'openstack',
      ]);

    $labels = $this->getDisplayLabels($entity_type_name);
    $update_method_name = 'update' . self::getCamelCaseWithoutWhitespace($labels['plural']);

    foreach ($cloud_configs ?: [] as $cloud_config) {
      $openstack_ec2_api = $cloud_config->field_use_openstack_ec2_api->value;

      $cloud_context = $cloud_config->getCloudContext();
      $resource_link = $cloud_config->getResourceLink($labels['plural'], $entity_type_name);
      $cloud_config_link = $cloud_config->getCloudConfigLink();
      try {
        $openstack_service = $this->openStackServiceFactory->get($cloud_context);
        $updated = $openstack_service->$update_method_name();

        $success_message = $this->t('Updated %resources of %cloud_config cloud service provider.', [
          '%resources' => $resource_link ?? $labels['plural'],
          '%cloud_config' => $cloud_config_link ?? $cloud_config->getName(),
        ]);

        $error_message = $this->t('Unable to update %resources of %cloud_config cloud service provider.', [
          '%resources' => $resource_link ?? $labels['plural'],
          '%cloud_config' => $cloud_config_link ?? $cloud_config->getName(),
        ]);

        $updated === TRUE
        ? $this->messageUser($success_message)
        : $this->messageUser($error_message, 'error');
      }
      catch (\Exception $e) {
        $this->messenger->addError($this->t('Unable to update @resources of @cloud_config cloud service provider.', [
          '@resources' => $labels['plural'],
          '@cloud_config' => $cloud_config->getName(),
        ]));
      }
    }

    // Update the cache.
    Ec2Service::clearCacheValue();

    return $this->redirect("view.$entity_type_name.all");
  }

}

==> cloud-3.2.0.tar.gz: cloud/modules/cloud_service_providers/openstack/src/Controller/ApiController.php <==
<?php

namespace Drupal\openstack\Controller;

use Drupal\aws_cloud\Service\Ec2\Ec2Service;
use Drupal\cloud\Plugin\cloud\config\CloudConfigPluginManagerInterface;
use Drupal\cloud\Traits\CloudContentEntityTrait;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Messenger\Messenger;
use Drupal\Core\Render\RendererInterface;
use Drupal\views\Views;
use Drupal\openstack\Service\OpenStackServiceFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Response;

/**
 * Api controller for interacting with OpenStack.
 */
class ApiController extends ControllerBase implements ApiControllerInterface {

  use CloudContentEntityTrait;

  /**
   * The OpenStack Service.
   *
   * @var \Drupal\openstack\Service\OpenStackServiceFactoryInterface
   */
  private $openStackServiceFactory;

  /**
   * The Messenger service.
   *
   * @var \Drupal\Core\Messenger\Messenger
   */
  protected $messenger;

  /**
   * Request stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  private $requestStack;

  /**
   * The cloud service provider plugin manager (CloudConfigPluginManager).
   *
   * @var \Drupal\cloud\Plugin\cloud\config\CloudConfigPluginManagerInterface
   */
  protected $cloudConfigPluginManager;

  /**
   * Renderer service.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  private $renderer;

  /**
   * ApiController constructor.
   *
   * @param \Drupal\openstack\Service\OpenStackServiceFactoryInterface $openstack_service_factory
   *   Object for interfacing with OpenStack Service.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The Entity type manager.
   * @param \Drupal\Core\Messenger\Messenger $messenger
   *   Messenger Object.
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   Request stack object.
   * @param \Drupal\cloud\Plugin\cloud\config\CloudConfigPluginManagerInterface $cloud_config_plugin_manager
   *   The cloud service provider plugin manager (CloudConfigPluginManager).
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   The renderer service.
   */
  public function __construct(OpenStackServiceFactoryInterface $openstack_service_factory,
                              EntityTypeManagerInterface $entityTypeManager,
                              Messenger $messenger,
                              RequestStack $request_stack,
                              CloudConfigPluginManagerInterface $cloud_config_plugin_manager,
                              RendererInterface $renderer) {
    $this->openStackServiceFactory = $openstack_service_factory;
    $this->entityTypeManager = $entityTypeManager;
    $this->messenger = $messenger;
    $this->requestStack = $request_stack;
    $this->cloudConfigPluginManager = $cloud_config_plugin_manager;
    $this->renderer = $renderer;
  }

  /**
   * Dependency Injection.
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   Instance of ContainerInterface.
   *
   * @return ApiController
   *   return created object.
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('openstack.factory'),
      $container->get('entity_type.manager'),
      $container->get('messenger'),
      $container->get('request_stack'),
      $container->get('plugin.manager.cloud_config_plugin'),
      $container->get('renderer')
    );
  }

  /**
   * Update message after refresh resources.
   *
   * @param string $resource_type
   *   Entity type name.
   * @param array $updated
   *   Updated statuses.
   */
  protected function updateMessages($resource_type, array $updated): void {
    $labels = $this->getDisplayLabels($resource_type);
    if (isset($updated[0])) {
      if ($updated[0]) {
        $this->messageUser($this->t('Updated @resource_name.', ['@resource_name' => $labels['plural']]));
      }
      else {
        $this->messageUser($this->t('Unable to update @resource_name.', ['@resource_name' => $labels['plural']]), 'error');
      }
    }
    Ec2Service::clearCacheValue();
  }

  /**
   * Update instances.
   *
   * @param string $cloud_context
   *   Cloud context string.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Redirect to instance list.
   */
  public function updateInstanceList($cloud_context = ''): RedirectResponse {
    return $this->updateResourceList('openstack_instance', $cloud_context);
  }

  /**
   * Update images.
   *
   * @param string $cloud_context
   *   Cloud context string.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Redirect to image list.
   */
  public function updateImageList($cloud_context = ''): RedirectResponse {
    return $this->updateResourceList('openstack_image', $cloud_context);
  }

  /**
   * Update key pairs.
   *
   * @param string $cloud_context
   *   Cloud context string.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Redirect to keypair list.
   */
  public function updateKeyPairList($cloud_context = ''): RedirectResponse {
    return $this->updateResourceList('openstack_key_pair', $cloud_context);
  }

  /**
   * Update security groups.
   *
   * @param string $cloud_context
   *   Cloud context string.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Redirect to security group list.
   */
  public function updateSecurityGroupList($cloud_context = ''): RedirectResponse {
    return $this->updateResourceList('openstack_security_group', $cloud_context);
  }

  /**
   * Update volumes.
   *
   * @param string $cloud_context
   *   Cloud context string.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Redirect to volume list.
   */
  public function updateVolumeList($cloud_context = ''): RedirectResponse {
    return $this->updateResourceList('openstack_volume', $cloud_context);
  }

  /**
   * Update snapshots.
   *
   * @param string $cloud_context
   *   Cloud context string.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Redirect to snapshot list.
   */
  public function updateSnapshotList($cloud_context = ''): RedirectResponse {
    return $this->updateResourceList('openstack_snapshot', $cloud_context);
  }

  /**
   * Update network interfaces.
   *
   * @param string $cloud_context
   *   Cloud context string.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Redirect to network interface list.
   */
  public function updateNetworkInterfaceList($cloud_context = ''): RedirectResponse {
    return $this->updateResourceList('openstack_network_interface', $cloud_context);
  }

  /**
   * Update floating ips.
   *
   * @param string $cloud_context
   *   Cloud context string.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Redirect to floating ip list.
   */
  public function updateFloatingIpList($cloud_context = ''): RedirectResponse {
    return $this->updateResourceList('openstack_floating_ip', $cloud_context);
  }

  /**
   * {@inheritdoc}
   */
  public function updateAll(): RedirectResponse {
    $regions = $this->requestStack->getCurrentRequest()->query->get('regions');
    if ($regions === NULL) {
      $this->messageUser($this->t('No region specified'), 'error');
    }
    else {
      $regions_array = explode(',', $regions);

      foreach ($regions_array ?: [] as $region) {
        $entity = $this->entityTypeManager()->getStorage('cloud_config')
          ->loadByProperties(
            [
              'cloud_context' => $region,
            ]);
        if ($entity) {
          openstack_update_resources(array_shift($entity));
        }
      }

      $this->messageUser($this->t('Creating cloud service provider was performed successfully.'));
      drupal_flush_all_caches();
    }
    return $this->redirect('entity.cloud_config.collection');
  }

  /**
   * {@inheritdoc}
   */
  public function listImageCallback(): Response {
    return $this->getViewResponse('openstack_image');
  }

  /**
   * Helper method to get views output.
   *
   * @param string $view_id
   *   The ID of list view.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   The response of list view.
   *
   * @throws \Exception
   *   Thrown when an object is passed in which cannot be printed.
   */
  private function getViewResponse($view_id): Response {
    $view = Views::getView($view_id);

    // Set the display machine name.
    $view->setDisplay('list');

    // Render the view as html, and return it as a response object.
    $build = $view->executeDisplay();
    return new Response($this->renderer->render($build));
  }

  /**
   * Helper method to add messages for the end user.
   *
   * @param string $message
   *   The message.
   * @param string $type
   *   The message type: error or message.
   */
  private function messageUser($message, $type = 'message'): void {
    switch ($type) {
      case 'error':
        $this->messenger->addError($message);
        break;

      case 'message':
        $this->messenger->addStatus($message);
        break;

      default:
        break;
    }
  }

  /**
   * Helper method to update entities.
   *
   * @param string $entity_type_name
   *   The entity type name.
   * @param string $cloud_context
   *   The cloud context.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   An associative array with a redirect route and any parameters to build
   *   the route.
   */
  private function updateResourceList($entity_type_name, $cloud_context): RedirectResponse {
    if (empty($cloud_context)) {
      return $this->updateAllResourceList($entity_type_name);
    }

    $labels = $this->getDisplayLabels($entity_type_name);
    $update_method_name = 'update' . self::getCamelCaseWithoutWhitespace($labels['plural']);
    $openstack_service = $this->openStackServiceFactory->get($cloud_context);
    $updated = $openstack_service->$update_method_name();

    if ($updated !== FALSE) {
      $this->messageUser($this->t('Updated @name.', ['@name' => $labels['plural']]));
    }
    else {
      $this->messageUser($this->t('Unable to update @name.', ['@name' => $labels['plural']]), 'error');
    }

    // Update the cache.
    Ec2Service::clearCacheValue();

    return $this->redirect("view.$entity_type_name.list", [
      'cloud_context' => $cloud_context,
    ]);
  }

  /**
   * Helper method to update all resource list.
   *
   * @param string $entity_type_name
   *   The entity type name.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   An associative array with a redirect route and any parameters to build
   *   the route.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  private function updateAllResourceList($entity_type_name): RedirectResponse {
    $cloud_configs = $this->entityTypeManager()
      ->getStorage('cloud_config')
      ->loadByProperties([
        'type' => 'openstack',
      ]);

    $labels = $this->getDisplayLabels($entity_type_name);
    $update_method_name = 'update' . self::getCamelCaseWithoutWhitespace($labels['plural']);

    foreach ($cloud_configs ?: [] as $cloud_config) {

      $cloud_context = $cloud_config->getCloudContext();
      $resource_link = $cloud_config->getResourceLink($labels['plural'], $entity_type_name);
      $cloud_config_link = $cloud_config->getCloudConfigLink();
      try {
        $openstack_service = $this->openStackServiceFactory->get($cloud_context);
        $updated = $openstack_service->$update_method_name();

        $success_message = $this->t('Updated %resources of %cloud_config cloud service provider.', [
          '%resources' => $resource_link ?? $labels['plural'],
          '%cloud_config' => $cloud_config_link ?? $cloud_config->getName(),
        ]);

        $error_message = $this->t('Unable to update %resources of %cloud_config cloud service provider.', [
          '%resources' => $resource_link ?? $labels['plural'],
          '%cloud_config' => $cloud_config_link ?? $cloud_config->getName(),
        ]);

        $updated === TRUE
        ? $this->messageUser($success_message)
        : $this->messageUser($error_message, 'error');
      }
      catch (\Exception $e) {
        $this->messenger->addError($this->t('Unable to update @resources of @cloud_config cloud service provider.', [
          '@resources' => $labels['plural'],
          '@cloud_config' => $cloud_config->getName(),
        ]));
      }
    }

    // Update the cache.
    Ec2Service::clearCacheValue();

    return $this->redirect("view.$entity_type_name.all");
  }

}
